@@ -561,25 +561,42 @@ class MIPPYMain(Frame):
 
     def filter_dicom_files(self):
         self.tag_list = []
-
+        errors = []
         if self.multiprocess and not (('win' in sys.platform and not 'darwin' in sys.platform)
                                 and len(self.path_list)<20):
             f = partial(collect_dicomdir_info,tempdir=self.tempdir)
             self.tag_list = multithread(f,self.path_list,progressbar=self.progress)
+
             self.tag_list = [item for sublist in self.tag_list for item in sublist]
             self.tag_list = [value for value in self.tag_list if value != []]
+            errors = [value for value in self.tag_list if value['state']=='ERROR']
+            # self.tag_list = [value for value in self.tag_list if not value in errors]
+            self.tag_list = [value for value in self.tag_list if value != None and not value['state']=='ERROR']
         else:
             for p in self.path_list:
                 self.progress(100*(float(self.path_list.index(p))/float(len(self.path_list))))
                 tags = collect_dicomdir_info(p,tempdir=self.tempdir)
                 if not tags is None:
                     for row in tags:
-                        self.tag_list.append(row)
+                        if not row['state']=='ERROR':
+                            self.tag_list.append(row)
+                        else:
+                            errors.append(row)
             self.progress(0.)
         # This should sort the list into your initial order for the tree - maybe implement a more customised sort if necessary?
         from operator import itemgetter
         self.sorted_list = sorted(self.tag_list, key=itemgetter('name','date','time','studyuid','series','seriesuid','instance','instanceuid'))
 
+        if len(errors)>0:
+            logpath = os.path.join(self.tempdir,'readerrors_log.txt')
+            with open(logpath,'w') as outfile:
+                logtext = []
+                for error in errors:
+                    logtext.append('-------------------------------\n{}\n{}'.format(error['path'],error['exception']))
+                outfile.write('\n'.join(logtext))
+            msg = "Some files could not be read. Please check the logfile at:\n{}".format(logpath)
+            tkinter.messagebox.showwarning("WARNING",msg)
+
         # Uncomment this block to enable mippydb objects in image directory
         #~ if self.ask_recursive:
             #~ self.mippydbpath = os.path.join(self.dicomdir,"mippydb_r")
@@ -674,7 +691,7 @@ class MIPPYMain(Frame):
         self.scan_modules_directory()
         return
 
-    def scan_modules_directory(self):
+    def scan_modules_directory(self,skip_update=False):
         # Remove old module eggs from sys.path
         # try:
         #     to_remove = []
@@ -707,6 +724,15 @@ class MIPPYMain(Frame):
         self.module_list.append(module_info)
         modules_to_backup = []
 
+        # dcmmodconfigpath = resource_filename('mippy.mdcmmod','config')
+        # with open(dcmmodconfigpath,'rb') as file_object:
+        #     module_info = pickle.load(file_object)
+        # module_info['dirname']='mippy.mdcmmod'
+        # module_info['version']=''
+        # module_info['eggpath']=None
+        # self.module_list.append(module_info)
+        # modules_to_backup = []
+
 
         if not (self.moduledir is None or not self.moduledir):
             for folder in os.listdir(self.moduledir):
@@ -731,7 +757,7 @@ class MIPPYMain(Frame):
                                 try:
                                     # print(pkg_info)
                                     # print('URL: {}'.format(pkg_info['Home-page']))
-                                    if 'api.bintray.com' in pkg_info['Home-page']:
+                                    if 'api.bintray.com' in pkg_info['Home-page'] and not skip_update:
                                         # Check if proxy required, and if proxy requires authentication
                                         proxies = None
                                         if len(self.proxy_list)>0:
@@ -898,7 +924,7 @@ class MIPPYMain(Frame):
                 os.makedirs(os.path.join(self.moduledir,'prev_versions'))
             for mod in modules_to_backup:
                 os.rename(mod,os.path.join(self.moduledir,'prev_versions',os.path.split(mod)[1]))
-            self.scan_modules_directory()
+            self.scan_modules_directory(skip_update=True)
 
         #~ self.master.progress = 50.
 
@@ -940,7 +966,15 @@ class MIPPYMain(Frame):
             #~ testing=''
         #~ info = 'Version '+version+'\n'+testing
         from subprocess import Popen,PIPE,check_output
-        output = check_output(['pip','show','mippy'])
+        try:
+            output = check_output(['pip','show','mippy'])
+        except FileNotFoundError:
+            try:
+                output = check_output(['pip3','show','mippy'])
+            except:
+                raise
+        except:
+            raise
         info = output
         tkinter.messagebox.showinfo("MIPPY: Version info",info)
         return
